@@ -1,15 +1,15 @@
 """Definition of messages received by bot or sent by it."""
 
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any, Dict, Optional, Tuple, Union
 from uuid import UUID
 
 from pydantic import BaseConfig, BaseModel, Field, validator
 
 from botx.models import events
-from botx.models.enums import ChatTypes, CommandTypes, EntityTypes
+from botx.models.attachments import AttachList
+from botx.models.entities import EntityList
+from botx.models.enums import ChatTypes, CommandTypes
 from botx.models.files import File
-from botx.models.forwards import Forward
-from botx.models.mentions import Mention
 
 CommandDataType = Union[
     events.ChatCreatedEvent,
@@ -101,18 +101,13 @@ class Sender(BaseModel):
         return None
 
 
-class Entity(BaseModel):
-    """Additional entity that can be received by bot."""
-
-    #: entity type.
-    type: EntityTypes  # noqa: WPS: 125
-
-    #: entity data.
-    data: Union[Forward, Mention]  # noqa: WPS110
-
-
 class IncomingMessage(BaseModel):
-    """Message that was received by bot and should be handled."""
+    """
+    Message that was received by bot and should be handled.
+
+    Warning:
+         `file` is deprecated field for botx api v4+.
+    """
 
     #: message event id on which bot should answer.
     sync_id: UUID
@@ -130,7 +125,10 @@ class IncomingMessage(BaseModel):
     bot_id: UUID
 
     #: additional entities that can be received by bot.
-    entities: List[Entity] = []
+    entities: EntityList = Field([])
+
+    #: attached documents and files to message.
+    attachments: AttachList = Field([])
 
     class Config(BaseConfig):
         allow_population_by_field_name = True
